@@ -21,7 +21,8 @@ from rest_framework import routers
 from django.urls import path
 from data.views.views import HardwareViewSet, AccessoryViewSet, CalibrationViewSet, ChannelViewSet, HubViewSet, \
     IOViewSet
-from django.contrib.auth import views as auth_views
+from django.contrib.auth.views import LoginView
+
 
 # Routers provide an easy way of automatically determining the URL conf.
 router = routers.DefaultRouter()
@@ -39,7 +40,7 @@ from data.views.views import video_streams
 # Additionally, we include login URLs for the browsable API.
 urlpatterns = [
     path('', include(router.urls)),
-    url(r'^login/$', auth_views.login, name='login'),
+    url(r'^login/$', LoginView, name='login'),
     path('api-auth/', include('rest_framework.urls', namespace='rest_framework')),
     # path('start', views.start, name='start'),
     # path('calibrate', views.start, name='calibrate'),
