@@ -766,3 +766,7 @@ class IOViewSet(viewsets.ModelViewSet):
             hardware_io.delete()
 
             return HttpResponse(render(request, 'accessories.html'))
+
+
+def video_streams(request):
+    return render(request, "streams.html", None)
\ No newline at end of file
